summaryrefslogtreecommitdiff
path: root/include/GL
diff options
context:
space:
mode:
authorIan Romanick <idr@us.ibm.com>2005-07-28 00:29:51 +0000
committerIan Romanick <idr@us.ibm.com>2005-07-28 00:29:51 +0000
commit1585c234e0db4bfb7cd85c4111594f6da1582e6f (patch)
tree75ead6349c299291829a8a47fe437f6c22bc50da /include/GL
parent9f23a3a1bff6c8af93e651273c9887bbf119f555 (diff)
Major rip-up of internal function insertion interface. The oldmesa_6_3_1
_glapi_add_entrypoint has been replaced by a new routine called _glapi_add_dispatch. This new routine dynamically assignes dispatch offsets to functions added. This allows IHVs to add support for extension functions that do not have assigned dispatch offsets. It also means that a driver has no idea what offset will be assigned to a function. The vast majority of the changes in this commit account for that. An additional table, driDispatchRemapTable, is added. Functions not in the Linux OpenGL ABI (i.e., anything not in GL 1.2 + ARB_multitexture) has a fixed offset in this new table. The entry in this table specifies the offset in of the function in the real dispatch table. The internal interface was also bumped from version 20050725 to 20050727. This has been tested with various programs in progs/demos on: radeon (Radeon Mobility M6) r128 (Rage 128 Pro) mga (G400)
Diffstat (limited to 'include/GL')
-rw-r--r--include/GL/internal/dri_interface.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/GL/internal/dri_interface.h b/include/GL/internal/dri_interface.h
index 08d3844266c..f4098ba8d91 100644
--- a/include/GL/internal/dri_interface.h
+++ b/include/GL/internal/dri_interface.h
@@ -113,7 +113,7 @@ typedef void *(CREATENEWSCREENFUNC)(__DRInativeDisplay *dpy, int scrn,
const __DRIinterfaceMethods * interface,
__GLcontextModes ** driver_modes);
typedef CREATENEWSCREENFUNC* PFNCREATENEWSCREENFUNC;
-extern CREATENEWSCREENFUNC __driCreateNewScreen_20050725;
+extern CREATENEWSCREENFUNC __driCreateNewScreen_20050727;
/**
@@ -377,7 +377,7 @@ struct __DRIcontextRec {
/**
* Method to bind a DRI drawable to a DRI graphics context.
*
* \since Internal API version 20050725.
*/
GLboolean (*bindContext)(__DRInativeDisplay *dpy, int scrn, __DRIid draw,
__DRIid read, __DRIcontext *ctx);
@@ -385,7 +385,7 @@ struct __DRIcontextRec {
/**
* Method to unbind a DRI drawable from a DRI graphics context.
*
* \since Internal API version 20050725.
*/
GLboolean (*unbindContext)(__DRInativeDisplay *dpy, int scrn, __DRIid draw,
__DRIid read, __DRIcontext *ctx);
@@ -377,7 +377,7 @@ struct __DRIcontextRec {
* Method to bind a DRI drawable to a DRI graphics context.
*
- * \since Internal API version 20050725.
+ * \since Internal API version 20050727.
*/
GLboolean (*bindContext)(__DRInativeDisplay *dpy, int scrn, __DRIid draw,
@@ -385,7 +385,7 @@ struct __DRIcontextRec {
* Method to unbind a DRI drawable from a DRI graphics context.
*
- * \since Internal API version 20050725.
+ * \since Internal API version 20050727.
*/
GLboolean (*unbindContext)(__DRInativeDisplay *dpy, int scrn, __DRIid draw,